# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## Unreleased

## 0.2.6
### Changed
- Fixed bugs with developer mode installation and jupyter notebook support
- Updated README.md

### Removed
- Depreciated `.cmd` launching in favor of `.exe` launching even in developer mode

## 0.2.5
### Added
- Automatic generation of .cmd launching script
- Automatic activation of virtual environment in launching

### Changed
- Documentation in root `README.md` to include command for development in virtual environment

### Removed
- Explicit tracking of .cmd files in repository, since they are now generated when manually built

## 0.2.4
### Added
- Support for virtual environments

### Changed
- Documentation in root `README.md` to explain use of virtual environments

### Removed
- Conda environment support
## 0.2.3
### Added
- Basic pip install capability from pypi.org
### Changed
- Documentation to reflect new pip installable package

## 0.2.2
### Added
- Basic test pypi functionality